/*
 * FILE:
 *   window.hpp
 *
 * PURPOSE:
 *   Class representing a Window. Windows can display graphics and
 *   receive keyboard and mouse input.
 *
 * AUTHOR:
 *   Stephen Thompson, 2008.
 *
 * COPYRIGHT:
 *   Public Domain.
 *
 */

#ifndef COERCRI_WINDOW_HPP
#define COERCRI_WINDOW_HPP

#include "boost/shared_ptr.hpp"
#include <vector>

namespace Coercri {

    class Rectangle;
    class Region;
    class WindowListener;
    
    class Window {
    public:
        Window() { }
        virtual ~Window() { }
        
        // get current window properties
        virtual void getSize(int &w, int &h) const = 0;
        
        // Query whether the window currently has focus
        virtual bool hasFocus() const = 0;

        // Mark a region (or the whole window) as needing to be repainted.
        virtual void invalidateRectangle(const Rectangle &rect) = 0;
        virtual void invalidateRegion(const Region &region) = 0;
        virtual void invalidateAll() = 0;

        // Switch between windowed and full screen
        virtual void switchToWindowed(int w, int h) = 0;
        virtual void switchToFullScreen(int w, int h) = 0;
        
        // WindowListeners for this window
        void addWindowListener(WindowListener *);
        void rmWindowListener(WindowListener *);

    protected:
        std::vector<WindowListener*> listeners;
        
    private:
        // prevent copying
        Window(const Window &);
        void operator=(const Window &);
    };

}

#endif
