/*
 * gui_draw_box.cpp
 *
 * Copyright (c) Stephen Thompson, 2008.
 * Licensed for non-commercial use only. See LICENCE.txt for details.
 *
 */

#include "gui_draw_box.hpp"

void GuiDrawBox(gcn::Graphics *graphics, const BoxCol &col, int left, int top, int width, int height)
{
    for (int y = 0; y < height; ++y) {
        const float lambda = float(y) / float(height-1);
        const int r = int(col.rtop + lambda*(col.rbot - col.rtop));
        const int g = int(col.gtop + lambda*(col.gbot - col.gtop));
        const int b = int(col.btop + lambda*(col.bbot - col.btop));
        graphics->setColor(gcn::Color(r, g, b));

        if (y > 1 && y < height-2) {
            graphics->drawLine(left+1, top+y, left+width-2, top+y);
        } else if (y == 1 || y == height-2) {
            graphics->drawLine(left+2, top+y, left+width-3, top+y);
        }

        // calculate border colour by multiplication
        const float multiple = 0.85 - 0.15 * lambda;
        graphics->setColor(gcn::Color(int(r*multiple), int(g*multiple), int(b*multiple)));

        if (y == 0 || y == height-1) {
            graphics->drawLine(left+2, top+y, left+width-3, top+y);
        } else if (y == 1 || y == height-2) {
            graphics->drawPoint(left+1, top+y);
            graphics->drawPoint(left+width-2, top+y);
        } else {
            graphics->drawPoint(left, top+y);
            graphics->drawPoint(left+width-1, top+y);
        }
    }
}
