/*
 * keyboard_controller.cpp
 *
 * Copyright (c) Stephen Thompson, 2008.
 * Licensed for non-commercial use only. See LICENCE.txt for details.
 *
 */

#include "keyboard_controller.hpp"

#include "coercri/gfx/window_listener.hpp"

class KeyboardListener : public Coercri::WindowListener {
public:
    explicit KeyboardListener(KeyboardController &kc_) : kc(kc_) { }
    virtual void onRawKeyDown(Coercri::RawKey k);
    virtual void onRawKeyUp(Coercri::RawKey k);

private:
    KeyboardController &kc;
};

KeyboardController::KeyboardController(Coercri::RawKey u, Coercri::RawKey r, Coercri::RawKey d,
                                       Coercri::RawKey l, Coercri::RawKey f, Coercri::RawKey s,
                                       shared_ptr<Coercri::Window> w)
    : kbd_listener(new KeyboardListener(*this)), win(w),
      up_key(u), right_key(r), down_key(d), left_key(l), fire_key(f), suicide_key(s),
      up(false), right(false), down(false), left(false), fire(false), suicide(false)
{
    for (int i=0; i<12; ++i) cheat[i] = false;
    win->addWindowListener(kbd_listener.get());
}

KeyboardController::~KeyboardController()
{
    win->rmWindowListener(kbd_listener.get());
}

void KeyboardController::get(MapDirection &dir, bool &centred, bool &fire_held,
                             bool &suicide_held) const
{
    fire_held = fire;
    suicide_held = suicide;
    centred = !up && !right && !down && !left;
    if (!centred) {
        if (up) dir = D_NORTH;
        else if (right) dir = D_EAST;
        else if (down) dir = D_SOUTH;
        else dir = D_WEST;
    }
}

int KeyboardController::getCheatKey() const
{
    for (int i=0; i<12; ++i) {
        if (cheat[i]) {
            return i+1;
        }
    }
    return 0;
}

void KeyboardListener::onRawKeyDown(Coercri::RawKey k)
{
    if (k == kc.up_key) kc.up = true;
    else if (k == kc.right_key) kc.right = true;
    else if (k == kc.down_key) kc.down = true;
    else if (k == kc.left_key) kc.left = true;
    else if (k == kc.fire_key) kc.fire = true;
    else if (k == kc.suicide_key) kc.suicide = true;
    else if (k >= Coercri::RK_F1 && k <= Coercri::RK_F12) kc.cheat[k-Coercri::RK_F1] = true;
}

void KeyboardListener::onRawKeyUp(Coercri::RawKey k)
{
    if (k == kc.up_key) kc.up = false;
    else if (k == kc.right_key) kc.right = false;
    else if (k == kc.down_key) kc.down = false;
    else if (k == kc.left_key) kc.left = false;
    else if (k == kc.fire_key) kc.fire = false;
    else if (k == kc.suicide_key) kc.suicide = false;
    else if (k >= Coercri::RK_F1 && k <= Coercri::RK_F12) kc.cheat[k-Coercri::RK_F1] = false;
}
