/*
 * options.cpp
 *
 * Copyright (c) Stephen Thompson, 2008.
 * Licensed for non-commercial use only. See LICENCE.txt for details.
 *
 */

#include "misc.hpp"

#include "cfg.hpp"
#include "options.hpp"

#include <cstring>

Options::Options()
{
    ctrls[0][0] = Coercri::RK_W;
    ctrls[0][1] = Coercri::RK_S;
    ctrls[0][2] = Coercri::RK_A;
    ctrls[0][3] = Coercri::RK_D;
    ctrls[0][4] = Coercri::RK_Q;
    ctrls[0][5] = Coercri::RK_F1;

    ctrls[1][0] = Coercri::RK_UP;
    ctrls[1][1] = Coercri::RK_DOWN;
    ctrls[1][2] = Coercri::RK_LEFT;
    ctrls[1][3] = Coercri::RK_RIGHT;
    ctrls[1][4] = Coercri::RK_RIGHT_CONTROL;
    ctrls[1][5] = Coercri::RK_F12;

    use_scale2x = true;
    fullscreen = true;
}

Options LoadOptions(std::istream &str)
{
    Options o;

    char buf[8];
    str.getline(buf, 6);
    if (std::strcmp(buf, "KOPT1") != 0) return Options();
    
    for (int i = 0; i < 2; ++i) {
        for (int j = 0; j < 6; ++j) {
            int x;
            str >> x;
            o.ctrls[i][j] = Coercri::RawKey(x);
        }
    }
    str >> o.use_scale2x;
    str >> o.fullscreen;
    if (!str) return Options();  // In case of load failure, return default options
    else return o;
}

void SaveOptions(const Options &o, std::ostream &str)
{
    str << "KOPT1\n";
    for (int i = 0; i < 2; ++i) {
        for (int j = 0; j < 6; ++j) {
            str << o.ctrls[i][j] << " ";
        }
        str << "\n";
    }
    str << o.use_scale2x << "\n";
    str << o.fullscreen << "\n";
}

int DefaultWindowWidth()
{
    // this should usually be set to 4*dpy_viewport_width + 2*dpy_gutter
    return CfgInt("default_window_width");
}

int DefaultWindowHeight()
{
    // this should usually be set to 4*dpy_viewport_width + 2*dpy_gutter
    // (or possibly a bit more, to allow room for the "Select Quest" screen)
    return CfgInt("default_window_height");
}
