/*
 * potion_renderer.hpp
 *
 * This draws the potion bottle, showing Knight's health and current magic.
 * 
 * Copyright (c) Stephen Thompson, 2008.
 * Licensed for non-commercial use only. See LICENCE.txt for details.
 *
 */

#ifndef POTION_RENDERER_HPP
#define POTION_RENDERER_HPP

#include "potion_magic.hpp"

#include "coercri/gfx/gfx_context.hpp"
#include "coercri/gfx/graphic.hpp"
#include "coercri/network/network_connection.hpp"

#include <vector>
using namespace std;

class ClientConfig;
class GfxManager;

class PotionRenderer {
public:
    //
    // setup
    //
    PotionRenderer();
    
    // Graphics, to be added in order of increasing health
    // (first for 0 health, second for 1 hitpoint, 3rd for 2 hitpoints etc)
    void addGraphic(const Coercri::Graphic *);

    // Colours, to be added in order of PotionMagics.
    void addColour(Coercri::Color col);

    //
    // drawing
    // (clip rectangle should be unset, will be taken care of by this func)
    //
    void draw(int gvt, Coercri::GfxContext &, GfxManager &, int health, PotionMagic magic, bool poison_immunity,
              int left, int top, float scale) const;

    //
    // serialization... (Graphics must have been serialized first.)
    //
    void serialize(Coercri::NetworkConnection &remote, const GfxManager &gm) const;
    PotionRenderer(Coercri::NetworkConnection &remote, ClientConfig &conf);
    
private:
    bool def_set;
    Coercri::Color def_col;
    vector<const Coercri::Graphic *> gfx;
    vector<ColourChange> colours;
};

#endif
