/*
 * screen.hpp
 *
 * Base class for game screens (menu screen, in game screen, etc)
 * 
 * Copyright (c) Stephen Thompson, 2008.
 * Licensed for non-commercial use only. See LICENCE.txt for details.
 *
 */

#ifndef SCREEN_HPP
#define SCREEN_HPP

#include "coercri/gfx/window.hpp"

#include "guichan.hpp"

#include "boost/shared_ptr.hpp"
using namespace boost;

class KnightsGame;

class Screen {
public:
    // This method starts the screen
    // Returns true if it wants gui enabled, or false if disabled.
    virtual bool start(KnightsGame &kg, shared_ptr<Coercri::Window> window, gcn::Gui &gui) = 0;

    // The destructor should stop the screen (or do nothing if start() wasn't called)
    virtual ~Screen() { }
    
    // getUpdateInterval: How often we want periodic updates (or 0 if we don't need this)
    // update: Do a periodic update (called by KnightsGame).
    // NOTE: update() ceases to be called after a successful requestScreenChange().
    virtual unsigned int getUpdateInterval() { return 0; }
    virtual void update() { }

    virtual unsigned int getMaxLag() { return getUpdateInterval() * 5; }
};

#endif
