/*
 * skull_renderer.cpp
 *
 * Copyright (c) Stephen Thompson, 2008.
 * Licensed for non-commercial use only. See LICENCE.txt for details.
 *
 */

#include "misc.hpp"

#include "client_config.hpp"
#include "gfx_manager.hpp"
#include "round.hpp"
#include "skull_renderer.hpp"

void SkullRenderer::addGraphic(const Coercri::Graphic *g)
{
    gfx.push_back(g);
}

void SkullRenderer::addColumn(int c)
{
    columns.push_back(c);
}

void SkullRenderer::addRow(int r)
{
    rows.push_back(r);
}

void SkullRenderer::draw(Coercri::GfxContext &gc, GfxManager &gm, int nsk, int left, int top, float scale_factor) const
{
    int r = 0;
    int c = 0;
    while (nsk > 0) {
        const int x = Round(float(columns[c])*scale_factor) + left;
        const int y = Round(float(rows[r])*scale_factor) + top;
        const int n = min(nsk, int(gfx.size()));
        const int w = Round(float(gfx[n-1]->getWidth()) * scale_factor);
        const int h = Round(float(gfx[n-1]->getHeight()) * scale_factor);
        gm.drawTransformedGraphic(gc, x, y, *gfx[n-1], w, h);
        nsk -= n;
        ++r;
        if (r >= rows.size()) {
            r = 0;
            ++c;
            if (c >= columns.size()) {
                // maximum number of skulls has been reached
                break;
            }
        }
    }
}

void SkullRenderer::serialize(Coercri::NetworkConnection &remote, const GfxManager &gm) const
{
    remote.putLong(gfx.size());
    for (int i=0; i<gfx.size(); ++i) {
        remote.putLong(gm.getGraphicID(*gfx[i]));
    }
    remote.putLong(rows.size());
    for (int i=0; i<rows.size(); ++i) remote.putLong(rows[i]);
    remote.putLong(columns.size());
    for (int i=0; i<columns.size(); ++i) remote.putLong(columns[i]);
}

SkullRenderer::SkullRenderer(Coercri::NetworkConnection &remote, ClientConfig &conf)
{
    int sz = remote.getLong();
    gfx.reserve(sz);
    for (int i=0; i<sz; ++i) addGraphic(conf.getGraphic(remote.getLong()));
    sz = remote.getLong();
    rows.reserve(sz);
    for (int i=0; i<sz; ++i) addRow(remote.getLong());
    sz = remote.getLong();
    columns.reserve(sz);
    for (int i=0; i<sz; ++i) addColumn(remote.getLong());
}

